Welcome to ClientVPS Mirrors

Help for package rfold
Type: Package
Title: Working with many R Folders Within an R Package
Version: 0.2.0
Description: Allows developers to work with many R folders inside a package. It offers functionalities to transfer R scripts (saved outside the R folder) into the R folder while making additional checks.
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/feddelegrand7/rfold
BugReports: https://github.com/feddelegrand7/rfold/issues
Imports: cli (≥ 3.6.1), fs (≥ 1.5.0), glue, here (≥ 1.0.1), usethis (≥ 2.0.1)
RoxygenNote: 7.1.1
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-02-12 15:37:05 UTC; Administrateur
Author: Mohamed El Fodil Ihaddaden [aut, cre]
Maintainer: Mohamed El Fodil Ihaddaden <ihaddaden.fodeil@gmail.com>
Repository: CRAN
Date/Publication: 2024-02-12 15:50:02 UTC

Transfer .R files into the R directory

Description

Transfer .R files into the R directory

Usage

rfold(folders_to_ignore = NULL, script_name_prefix = "DO_NOT_EDIT_")

Arguments

folders_to_ignore

a string vector of plain names folders that should be ignored where transferring .R files into the main R folder (for example a dev folder). Defaults to NULL

script_name_prefix

characters string of length 1 that will be appended to the start of the .R scripts when transferring them to the R folder. Defaults to 'DO_NOT_EDIT', set it to NULL for no appending

Value

called for the side effect of transferring all R files

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.